@@ -86,6 +86,7 @@ class CleaningBase(Term):
         Returns:
             pd.DataFrame: raw dataset
         """
+        warnings.filterwarnings("ignore", category=DeprecationWarning)
         kwargs = {
             "low_memory": False, "dtype": dtype, "header": header, "usecols": columns}
         try:
@@ -125,24 +126,29 @@ class CleaningBase(Term):
     def citation(self, description):
         self._citation = str(description)
 
-    def ensure_country_name(self, country):
+    def ensure_country_name(self, country, errors="raise"):
         """
         Ensure that the country name is correct.
         If not, the correct country name will be found.
 
         Args:
             country (str): country name
+            errors (str): 'raise' or 'coerce'
 
         Returns:
             str: country name
+
+        Raises:
+            SubsetNotFoundError: no records were found for the country and @errors is 'raise'
         """
-        df = self._ensure_dataframe(
-            self._cleaned_df, name="the cleaned dataset", columns=[self.COUNTRY])
+        df = self._cleaned_df.copy()
+        self._ensure_dataframe(df, name="the cleaned dataset", columns=[self.COUNTRY])
         selectable_set = set(df[self.COUNTRY].unique())
         # return country name as-is if selectable
         if country in selectable_set:
             return country
         # Convert country name
+        warnings.simplefilter("ignore", FutureWarning)
         converted = coco.convert(country, to="name_short", not_found=None)
         # Additional abbr
         abbr_dict = {
@@ -155,7 +161,8 @@ class CleaningBase(Term):
         # Return the name if registered in the dataset
         if name in selectable_set:
             return name
-        raise SubsetNotFoundError(country=country, country_alias=name)
+        if errors == "raise":
+            raise SubsetNotFoundError(country=country, country_alias=name)
 
     @deprecate("CleaningBase.iso3_to_country()", new="CleaningBase.ensure_country_name()")
     def iso3_to_country(self, iso3_code):
@@ -210,33 +217,77 @@ class CleaningBase(Term):
             return country
         return f"{country}{cls.SEP}{province}"
 
+    def layer(self, country=None):
+        """
+        Return the cleaned data at the selected layer.
+
+        Args:
+            country (str or None): country name or None (country level data or country-specific dataset)
+
+        Returns:
+            pandas.DataFrame:
+                Index
+                    reset index
+                Columns
+                - Country (str): country names
+                - Province (str): province names (or removed when country level data)
+                - any other columns of the cleaned data
+
+        Raises:
+            SubsetNotFoundError: no records were found for the country (when @country is not None)
+            KeyError: @country was None, but country names were not registered in the dataset
+
+        Note:
+            When @country is None, country level data will be returned.
+            When @country is a country name, province level data in the selected country will be returned.
+        """
+        df = self._cleaned_df.copy()
+        self._ensure_dataframe(df, name="the cleaned dataset", columns=[self.COUNTRY])
+        if self.PROVINCE not in df:
+            df[self.PROVINCE] = self.UNKNOWN
+        df[self.AREA_COLUMNS] = df[self.AREA_COLUMNS].astype(str)
+        # Country level data
+        if country is None:
+            df = df.loc[df[self.PROVINCE] == self.UNKNOWN]
+            return df.drop(self.PROVINCE, axis=1).reset_index(drop=True)
+        # Province level data at the selected country
+        country_alias = self.ensure_country_name(country, errors="coerce")
+        df = df.loc[df[self.COUNTRY] == country_alias]
+        if df.empty:
+            raise SubsetNotFoundError(country=country, country_alias=country_alias) from None
+        df = df.loc[df[self.PROVINCE] != self.UNKNOWN]
+        return df.reset_index(drop=True)
+
     def _subset_by_area(self, country, province=None):
         """
         Return subset for the country/province.
 
         Args:
             country (str): country name
-            province (str or None): province name
+            province (str or None): province name or None (country level data)
 
         Returns:
-            pandas.DataFrame: subset for the country/province
+            pandas.DataFrame: subset for the country/province, columns are not changed
+
+        Raises:
+            SubsetNotFoundError: no records were found for the condition
         """
         # Country level
-        country = self.ensure_country_name(country)
-        df = self._ensure_dataframe(
-            self._cleaned_df, name="the cleaned dataset", columns=[self.COUNTRY])
-        df = df.loc[df[self.COUNTRY] == country, :]
+        if province is None or province == self.UNKNOWN:
+            df = self.layer(country=None)
+            country_alias = self.ensure_country_name(country)
+            df = df.loc[df[self.COUNTRY] == country_alias]
+            return df.reset_index(drop=True)
         # Province level
-        province = province or self.UNKNOWN
-        if self.PROVINCE not in df.columns and province == self.UNKNOWN:
-            return df
-        df = self._ensure_dataframe(
-            df, "the cleaned dataset", columns=[self.PROVINCE])
-        return df.loc[df[self.PROVINCE] == province, :]
+        df = self.layer(country=country)
+        df = df.loc[df[self.PROVINCE] == province]
+        if df.empty:
+            raise SubsetNotFoundError(country=country)
+        return df.reset_index(drop=True)
 
     def subset(self, country, province=None, start_date=None, end_date=None):
         """
-        Return subset of the country/province and start/end date.
+        Return subset with country/province name and start/end date.
 
         Args:
             country (str): country name or ISO3 code
@@ -250,19 +301,21 @@ class CleaningBase(Term):
                     reset index
                 Columns
                     without ISO3, Country, Province column
+
+        Raises:
+            SubsetNotFoundError: no records were found for the condition
         """
-        country_alias = self.ensure_country_name(country)
-        df = self._subset_by_area(country=country, province=province)
-        df = df.drop(
-            [self.COUNTRY, self.ISO3, self.PROVINCE], axis=1, errors="ignore")
-        if df.empty:
+        country_alias = self.ensure_country_name(country, errors="coerce")
+        try:
+            df = self._subset_by_area(country=country, province=province)
+        except SubsetNotFoundError:
             raise SubsetNotFoundError(
-                country=country, country_alias=country_alias, province=province)
+                country=country, country_alias=country_alias, province=province) from None
+        df = df.drop([self.COUNTRY, self.ISO3, self.PROVINCE], axis=1, errors="ignore")
         # Subset with Start/end date
         if start_date is None and end_date is None:
             return df.reset_index(drop=True)
-        df = self._ensure_dataframe(
-            df, name="the cleaned dataset", columns=[self.DATE])
+        df = self._ensure_dataframe(df, name="the cleaned dataset", columns=[self.DATE])
         series = df[self.DATE].copy()
         start_obj = self.date_obj(date_str=start_date, default=series.min())
         end_obj = self.date_obj(date_str=end_date, default=series.max())
@@ -270,7 +323,7 @@ class CleaningBase(Term):
         if df.empty:
             raise SubsetNotFoundError(
                 country=country, country_alias=country_alias, province=province,
-                start_date=start_date, end_date=end_date)
+                start_date=start_date, end_date=end_date) from None
         return df.reset_index(drop=True)
 
     def subset_complement(self, country, **kwargs):
@@ -371,7 +424,8 @@ class CleaningBase(Term):
         # Remove cruise ships
         df = df.loc[df[self.COUNTRY] != self.OTHERS]
         # Select country level data
-        df = df.loc[df[self.PROVINCE] == self.UNKNOWN]
+        if self.PROVINCE in df.columns:
+            df = df.loc[df[self.PROVINCE] == self.UNKNOWN]
         # Select date
         if date is not None:
             self._ensure_dataframe(df, name="cleaned dataset", columns=[self.DATE])
