@@ -25,9 +25,12 @@ class JapanData(CountryData):
             - Infected (int): the number of currently infected cases
             - Fatal (int): the number of fatal cases
             - Recovered (int): the number of recovered cases
-            - Tested (int): the number of tested persons
+            - Tests (int): the number of tested persons
             - Moderate (int): the number of cases who requires hospitalization but not severe
             - Severe (int): the number of severe cases
+            - Vaccinations (int): cumulative number of vaccinations
+            - Vaccinated_once (int): cumulative number of people who received at least one vaccine dose
+            - Vaccinated_full (int): cumulative number of people who received all doses prescrived by the protocol
     """
     GITHUB_URL = "https://raw.githubusercontent.com"
     URL_C = f"{GITHUB_URL}/lisphilar/covid19-sir/master/data/japan/covid_jpn_total.csv"
@@ -41,6 +44,7 @@ class JapanData(CountryData):
     JAPAN_VALUE_COLS = [
         CountryData.C, CountryData.CI, CountryData.F, CountryData.R,
         CountryData.TESTS, MODERATE, SEVERE,
+        CountryData.VAC, CountryData.V_ONCE, CountryData.V_FULL,
     ]
     JAPAN_COLS = [
         CountryData.DATE, CountryData.COUNTRY, CountryData.PROVINCE,
@@ -61,7 +65,10 @@ class JapanData(CountryData):
     def __init__(self, filename, force=False, verbose=1):
         Path(filename).parent.mkdir(exist_ok=True, parents=True)
         if Path(filename).exists() and not force:
-            self._raw = self.load(filename)
+            try:
+                self._raw = self.load(filename)
+            except KeyError:
+                self._raw = self._retrieve(filename=filename, verbose=verbose)
         else:
             self._raw = self._retrieve(filename=filename, verbose=verbose)
         self._cleaned_df = self._cleaning()
@@ -70,6 +77,8 @@ class JapanData(CountryData):
             "https://github.com/lisphilar/covid19-sir/data/japan"
         self.dir_path = Path(filename).parent
         self.verbose = verbose
+        # Directory that save the file
+        self._dirpath = Path(filename or "input").resolve().parent
 
     def _retrieve(self, filename, verbose=1):
         """
@@ -84,18 +93,16 @@ class JapanData(CountryData):
         """
         # Show URL
         if verbose:
-            print(
-                "Retrieving COVID-19 dataset in Japan from https://github.com/lisphilar/covid19-sir/data/japan")
+            print("Retrieving COVID-19 dataset in Japan from https://github.com/lisphilar/covid19-sir/data/japan")
         # Download the dataset at country level
         cols = [
             "Area", "Date", "Positive",
             "Tested", "Discharged", "Fatal", "Hosp_require", "Hosp_severe",
         ]
-        c_df = self.load(self.URL_C, header=0).rename(
-            {"Location": "Area"}, axis=1)[cols]
+        cols_v = ["Vaccinated_1st", "Vaccinated_2nd"]
+        c_df = self.load(self.URL_C, header=0).rename({"Location": "Area"}, axis=1)[cols + cols_v]
         # Download the datset at province level
-        p_df = self.load(self.URL_P, header=0).rename(
-            {"Prefecture": "Area"}, axis=1)[cols]
+        p_df = self.load(self.URL_P, header=0).rename({"Prefecture": "Area"}, axis=1)[cols]
         # Combine the datsets
         df = pd.concat([c_df, p_df], axis=0, ignore_index=True, sort=True)
         # Save the raw data
@@ -132,7 +139,29 @@ class JapanData(CountryData):
             lambda x: x.set_index(self.DATE).resample("D").interpolate("linear", limit_direction="both"))
         df = df.fillna(0).drop(self.PROVINCE, axis=1).reset_index()
         df = df.sort_values(self.DATE).reset_index(drop=True)
-        # Records at country level (Domestic/Airport/Returnee) and entering Japan(Airport/Returnee)
+        # Moderate
+        df[self.MODERATE] = df["Hosp_require"] - df[self.SEVERE]
+        # Vaccinations
+        v_raw_cols = ["Vaccinated_1st", "Vaccinated_2nd"]
+        v_df = self._raw.loc[:, ["Area", "Date", *v_raw_cols]].rename(
+            columns={"Area": self.PROVINCE, "Date": self.DATE})
+        v_df[self.DATE] = pd.to_datetime(v_df[self.DATE])
+        for col in v_raw_cols:
+            v_df[col] = pd.to_numeric(v_df[col], errors="coerce").fillna(0)
+        v_1st = v_df.groupby(self.PROVINCE)["Vaccinated_1st"].cumsum().fillna(0)
+        v_2nd = v_df.groupby(self.PROVINCE)["Vaccinated_2nd"].cumsum().fillna(0)
+        v_sum_df = pd.DataFrame(
+            {
+                self.PROVINCE: v_df[self.PROVINCE],
+                self.DATE: v_df[self.DATE],
+                self.VAC: v_1st + v_2nd,
+                self.V_ONCE: v_1st,
+                self.V_FULL: v_2nd,
+            }
+        )
+        df = df.drop(v_raw_cols, axis=1).merge(
+            v_sum_df, how="left", on=[self.PROVINCE, self.DATE]).reset_index(drop=True)
+        # Records at country level (Domestic/Airport/Returnee) and entering Japan (Airport/Returnee)
         e_cols = ["Airport", "Returnee"]
         e_df = df.loc[df[self.PROVINCE].isin(e_cols)].groupby(self.DATE).sum()
         e_df[self.PROVINCE] = "Entering"
@@ -146,8 +175,6 @@ class JapanData(CountryData):
                 c_df.reset_index(),
             ],
             ignore_index=True, sort=True)
-        # Moderate
-        df[self.MODERATE] = df["Hosp_require"] - df[self.SEVERE]
         # Value columns
         df[self.CI] = df[self.C] - df[self.F] - df[self.R]
         df[self.JAPAN_VALUE_COLS] = df[self.JAPAN_VALUE_COLS].astype(np.int64)
@@ -173,8 +200,7 @@ class JapanData(CountryData):
         """
         # Show URL
         if verbose:
-            print(
-                "Retrieving Metadata of Japan dataset from https://github.com/lisphilar/covid19-sir/data/japan")
+            print("Retrieving Metadata of Japan dataset from https://github.com/lisphilar/covid19-sir/data/japan")
         df = self.load(self.URL_M)
         df.to_csv(filename, index=False)
         return df
