@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import numpy as np
-from covsirphy.cleaning.term import Term
+from covsirphy.util.term import Term
 
 
 class ModelBase(Term):
@@ -39,16 +39,15 @@ class ModelBase(Term):
             population (int): total population
         """
         # Total population
-        self.population = self.ensure_natural_int(
+        self.population = self._ensure_natural_int(
             population, name="population"
         )
         # Dictionary of non-dim parameters: {name: value}
         self.non_param_dict = {}
 
     def __str__(self):
-        param_str = ", ".join(
-            [f"{p}={v}" for (p, v) in self.non_param_dict.items()]
-        )
+        param_str = ", ".join(f"{p}={v}" for (
+            p, v) in self.non_param_dict.items())
         return f"{self.NAME} model with {param_str}"
 
     def __getitem__(self, key):
@@ -78,9 +77,9 @@ class ModelBase(Term):
 
         Args:
             taufree_df (pandas.DataFrame):
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - t (int): time steps (tau-free)
                     - columns with dimensional variables
             population (int): total population
@@ -100,9 +99,9 @@ class ModelBase(Term):
 
         Args:
             data_df (pandas.DataFrame):
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
                     - Fatal (int): the number of fatal cases
@@ -112,9 +111,9 @@ class ModelBase(Term):
 
         Returns:
             (pandas.DataFrame):
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - any columns @data_df has
                     - columns with dimensional variables
         """
@@ -129,17 +128,17 @@ class ModelBase(Term):
         Args:
             specialized_df (pandas.DataFrame): dataframe with the variables
 
-                Index:
+                Index
                     (object):
-                Columns:
+                Columns
                     - variables of the models (int)
                     - any columns
 
         Returns:
             (pandas.DataFrame):
-                Index:
+                Index
                     (object): as-is
-                Columns:
+                Columns
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
                     - Fatal (int): the number of fatal cases
@@ -186,9 +185,9 @@ class ModelBase(Term):
 
         Args:
             subset_df (pandas.DataFrame):
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
@@ -200,9 +199,9 @@ class ModelBase(Term):
 
         Returns:
             (pandas.DataFrame):
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - t (int): if tau is not None
                     - columns with dimensional variables
         """
@@ -210,8 +209,8 @@ class ModelBase(Term):
         if tau is None:
             df = df.drop(cls.DATE, axis=1)
             return cls.specialize(df, population=population).reset_index(drop=True)
-        tau = cls.ensure_tau(tau)
-        df = cls.ensure_dataframe(
+        tau = cls._ensure_tau(tau)
+        df = cls._ensure_dataframe(
             df, name="data_df", columns=cls.NLOC_COLUMNS)
         # Calculate elapsed time from the first date [min]
         df[cls.T] = (df[cls.DATE] - df[cls.DATE].min()).dt.total_seconds()
