@@ -3,7 +3,7 @@
 
 import numpy as np
 import pandas as pd
-from covsirphy.cleaning.term import Term
+from covsirphy.util.term import Term
 from covsirphy.phase.phase_unit import PhaseUnit
 from covsirphy.phase.sr_change import ChangeFinder
 
@@ -19,9 +19,9 @@ class PhaseSeries(Term):
     """
 
     def __init__(self, first_date, last_date, population):
-        self.first_date = self.ensure_date(first_date, "first_date")
-        self.last_date = self.ensure_date(last_date, "last_date")
-        self.init_population = self.ensure_population(population)
+        self.first_date = self._ensure_date(first_date, "first_date")
+        self.last_date = self._ensure_date(last_date, "last_date")
+        self.init_population = self._ensure_population(population)
         # List of PhaseUnit
         self._units = []
         self.clear(include_past=True)
@@ -42,7 +42,7 @@ class PhaseSeries(Term):
         Returns:
             covsirphy.PhaseUnit: the unit of the phase
 
-        Notes:
+        Note:
             When @phase is 'last' and no phases were registered, returns A phase
             with the start/end dates are the previous date of the first date and initial population value.
         """
@@ -85,7 +85,7 @@ class PhaseSeries(Term):
             str: end date
         """
         if end_date is not None:
-            self.ensure_date_order(start_date, end_date, name="end_date")
+            self._ensure_date_order(start_date, end_date, name="end_date")
             return end_date
         if days is None:
             return self.last_date
@@ -106,7 +106,7 @@ class PhaseSeries(Term):
         Returns:
             covsirphy.PhaseSeries: self
 
-        Notes:
+        Note:
             If @population is None, the previous initial value will be used.
             When addition of past phases was not completed and the new phase is future phase, fill in the blank.
         """
@@ -115,7 +115,8 @@ class PhaseSeries(Term):
         start_date = self.tomorrow(last_unit.end_date)
         end_date = self._calc_end_date(
             start_date, end_date=end_date, days=days)
-        population = self.ensure_population(population or last_unit.population)
+        population = self._ensure_population(
+            population or last_unit.population)
         model = model or last_unit.model
         tau = last_unit.tau or tau
         if model is None:
@@ -151,7 +152,7 @@ class PhaseSeries(Term):
         Returns:
             covsirphy.PhaseSeries: self
 
-        Notes:
+        Note:
             When @phase is '0th', disable 0th phase. 0th phase will not be deleted.
             When @phase is 'last', the last phase will be deleted.
         """
@@ -221,9 +222,9 @@ class PhaseSeries(Term):
 
         Returns:
             (pandas.DataFrame):
-                Index:
+                Index
                     - phase name, like 1st, 2nd, 3rd...
-                Columns:
+                Columns
                     - Type: 'Past' or 'Future'
                     - Start: start date of the phase
                     - End: end date of the phase
@@ -286,7 +287,7 @@ class PhaseSeries(Term):
         Returns:
             covsirphy.PhaseSeries: self
 
-        Notes:
+        Note:
             If @phase is None and @keep_old is False, all old phases will be deleted.
             If @phase is not None, the phase will be deleted.
             @new_list must be specified.
@@ -321,7 +322,7 @@ class PhaseSeries(Term):
             ValueError: Phases are not series.
         """
         sorted_units = sorted(units)
-        s = ", ".join([str(unit) for unit in sorted_units])
+        s = ", ".join(str(unit) for unit in sorted_units)
         for (i, unit) in enumerate(sorted_units):
             if i in [0, len(sorted_units) - 1]:
                 continue
@@ -340,13 +341,14 @@ class PhaseSeries(Term):
 
         Args:
             sr_df (pandas.DataFrame): susceptible and recovered records
-                Index:
+
+                Index
                     Date (pd.TimeStamp): Observation date
-                Columns:
+                Columns
                     - Recovered (int): the number of recovered cases (> 0)
                     - Susceptible (int): the number of susceptible cases
                     - any other columns will be ignored
-            kwargs: keyword arguments of ChangeFinder()
+            kwargs: keyword arguments of covsirphy.ChangeFinder()
 
         Returns:
             covsirphy.PhaseSeries: self
@@ -363,21 +365,21 @@ class PhaseSeries(Term):
         [self.add(end_date=end_date) for end_date in end_dates]
         return self
 
-    def trend_show(self, sr_df, area=None, filename=None):
+    def trend_show(self, sr_df, area=None, **kwargs):
         """
         Show S-R plane, indicating change points found with S-R trend analysis.
 
         Args:
             sr_df (pandas.DataFrame): susceptible and recovered records
-                Index:
-                    Date (pd.TimeStamp): Observation date
-                Columns:
+
+                Index
+                    Date (pandas.TimeStamp): Observation date
+                Columns
                     - Recovered (int): the number of recovered cases (> 0)
                     - Susceptible (int): the number of susceptible cases
                     - any other columns will be ignored
             area (str or None): area name
-            filename (str): filename of the figure, or None (display)
-            kwargs: keyword arguments of ChangeFinder()
+            kwargs: keyword arguments of covsirphy.line_plot_multiple()
 
         Returns:
             covsirphy.PhaseSeries: self
@@ -389,8 +391,7 @@ class PhaseSeries(Term):
         finder = ChangeFinder(sr_df)
         change_dates = [
             unit.start_date for unit in self._units[1:] if unit <= self.last_date]
-        finder.show(
-            area=area, change_dates=change_dates, filename=filename)
+        finder.show(area=area, change_dates=change_dates, **kwargs)
 
     def simulate(self, record_df, y0_dict=None):
         """
@@ -398,9 +399,9 @@ class PhaseSeries(Term):
 
         Args:
             record_df (pandas.DataFrame):
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
@@ -413,9 +414,9 @@ class PhaseSeries(Term):
 
         Returns:
             pandas.DataFrame
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Country (str): country/region name
                     - Province (str): province/prefecture/state name
