@@ -11,7 +11,7 @@ import pandas as pd
 import seaborn as sns
 from sklearn.metrics import mean_squared_log_error
 from covsirphy.util.stopwatch import StopWatch
-from covsirphy.cleaning.term import Term
+from covsirphy.util.term import Term
 from covsirphy.ode.mbase import ModelBase
 from covsirphy.simulation.simulator import ODESimulator
 
@@ -22,9 +22,9 @@ class Estimator(Term):
 
     Args:
         record_df (pandas.DataFrame)
-            Index:
+            Index
                 reset index
-            Columns:
+            Columns
                 - Date (pd.TimeStamp): Observation date
                 - Confirmed (int): the number of confirmed cases
                 - Infected (int): the number of currently infected cases
@@ -43,17 +43,17 @@ class Estimator(Term):
 
     def __init__(self, record_df, model, population, tau=None, **kwargs):
         # ODE model
-        self.model = self.ensure_subclass(model, ModelBase, name="model")
+        self.model = self._ensure_subclass(model, ModelBase, name="model")
         self.variables = model.VARIABLES[:]
         self.variables_evaluate = [
             v for (v, p) in zip(model.VARIABLES, model.WEIGHTS) if p > 0]
         # Dataset
         if not set(self.NLOC_COLUMNS).issubset(record_df.columns):
             record_df = model.restore(record_df)
-        self.record_df = self.ensure_dataframe(
+        self.record_df = self._ensure_dataframe(
             record_df, name="record_df", columns=self.NLOC_COLUMNS)
         # Settings for simulation
-        self.population = self.ensure_population(population)
+        self.population = self._ensure_population(population)
         df = model.tau_free(self.record_df, population, tau=None)
         self.y0_dict = {
             k: df.loc[df.index[0], k] for k in model.VARIABLES}
@@ -67,7 +67,7 @@ class Estimator(Term):
         self.total_trials = 0
         self.runtime = 0
         # Tau value
-        self.tau_final = self.ensure_tau(tau)
+        self.tau_final = self._ensure_tau(tau)
         self.tau_candidates = self.divisors(1440)
         self.tau = tau
         if tau is None:
@@ -76,51 +76,80 @@ class Estimator(Term):
         else:
             self._set_taufree()
 
-    def _init_study(self, seed):
+    def _init_study(self, seed, pruner, upper, percentile):
         """
         Initialize Optuna study.
 
         Args:
             seed (int or None): random seed of hyperparameter optimization
+            pruner (str): Hyperband, Median, Threshold or Percentile
+            upper (float): works for "threshold" pruner,
+                intermediate RMSLE score is larger than this value, it prunes
+            percentile (float): works for "threshold" pruner,
+                the best intermediate value is in the bottom percentile among trials, it prunes
         """
-        self.study = optuna.create_study(
-            direction="minimize",
-            sampler=optuna.samplers.TPESampler(seed=seed)
-        )
+        pruner_dict = {
+            "hyperband": optuna.pruners.HyperbandPruner(),
+            "median": optuna.pruners.MedianPruner(),
+            "threshold": optuna.pruners.ThresholdPruner(upper=upper),
+            "percentile": optuna.pruners.PercentilePruner(percentile=percentile),
+        }
+        try:
+            self.study = optuna.create_study(
+                direction="minimize",
+                sampler=optuna.samplers.TPESampler(seed=seed),
+                pruner=pruner_dict[pruner.lower()],
+            )
+        except KeyError:
+            raise KeyError(
+                f"@pruner should be selected from {', '.join(pruner_dict.keys())}.")
 
-    def run(self, timeout=180, reset_n_max=3,
-            timeout_iteration=10, allowance=(0.98, 1.02), seed=0, **kwargs):
+    def run(self, timeout=180, reset_n_max=3, timeout_iteration=10, tail_n=4, allowance=(0.98, 1.02),
+            seed=0, pruner="threshold", upper=0.5, percentile=50, **kwargs):
         """
         Run optimization.
         If the result satisfied the following conditions, optimization ends.
-        - all values are not under than 0
-        - values of monotonic increasing variables increases monotonically
-        - predicted values are in the allowance when each actual value shows max value
+        - RMSLE score did not change in the last @tail_n iterations.
+        - Monotonic increasing variables increases monotonically.
+        - Predicted values are in the allowance when each actual value shows max value.
 
         Args:
             timeout (int): timeout of optimization
             reset_n_max (int): if study was reset @reset_n_max times, will not be reset anymore
             timeout_iteration (int): time-out of one iteration
+            tail_n (int): the number of iterations to decide whether RMSLE score did not change for the last iterations
             allowance (tuple(float, float)): the allowance of the predicted value
             seed (int or None): random seed of hyperparameter optimization
+            pruner (str): hyperband, median, threshold or percentile
+            upper (float): works for "threshold" pruner,
+                intermediate RMSLE score is larger than this value, it prunes
+            percentile (float): works for "Percentile" pruner,
+                the best intermediate value is in the bottom percentile among trials, it prunes
             kwargs: other keyword arguments will be ignored
 
-        Notes:
+        Note:
             @n_jobs was obsoleted because this is not effective for Optuna.
         """
         # Create a study of optuna
         if self.study is None:
-            self._init_study(seed=seed)
+            self._init_study(
+                seed=seed, pruner=pruner, upper=upper, percentile=percentile)
         reset_n = 0
         iteration_n = math.ceil(timeout / timeout_iteration)
         increasing_cols = [f"{v}{self.P}" for v in self.model.VARS_INCLEASE]
         stopwatch = StopWatch()
+        rmsle_scores = []
         for _ in range(iteration_n):
             # Perform optimization
             self.study.optimize(
                 self._objective, n_jobs=1, timeout=timeout_iteration)
+            # If RMSLE did not change in the last iterations, stop running
+            tau, param_dict = self._param()
+            rmsle_scores.append(self._rmsle(tau=tau, param_dict=param_dict))
+            if len(rmsle_scores) >= tail_n and len(set(rmsle_scores[-tail_n:])) == 1:
+                break
             # Create a table to compare observed/estimated values
-            comp_df = self._compare(*self._param())
+            comp_df = self._compare(tau=tau, param_dict=param_dict)
             # Check monotonic variables
             mono_ok_list = [
                 comp_df[col].is_monotonic_increasing for col in increasing_cols
@@ -239,9 +268,9 @@ class Estimator(Term):
 
         Returns:
             pandas.DataFrame:
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - t (int): Elapsed time divided by tau value [-]
                     - columns with dimensionalized variables
         """
@@ -265,9 +294,9 @@ class Estimator(Term):
 
         Returns:
             pandas.DataFrame:
-                Index:
+                Index
                     t (int): Elapsed time divided by tau value [-]
-                Columns:
+                Columns
                     - columns with "_actual"
                     - columns with "_predicted:
                     - columns are defined by self.variables
@@ -378,9 +407,9 @@ class Estimator(Term):
 
         Returns:
             pandas.DataFrame:
-                Index:
+                Index
                     t (int): Elapsed time divided by tau value [-]
-                Columns:
+                Columns
                     - columns with "_actual"
                     - columns with "_predicted:
                     - columns are defined by self.variables
@@ -398,13 +427,12 @@ class Estimator(Term):
         # Prepare figure object
         val_len = len(variables) + 1
         fig, axes = plt.subplots(
-            ncols=1, nrows=val_len, figsize=(9, 6 * val_len / 2)
-        )
+            ncols=1, nrows=val_len, figsize=(9, 6 * val_len / 2))
         # Comparison of each variable
         for (ax, v) in zip(axes.ravel()[1:], variables):
             df[[f"{v}{self.A}", f"{v}{self.P}"]].plot.line(
-                ax=ax, ylim=(0, None), sharex=True,
-                title=f"{self.model.NAME}: Comparison of observed/estimated {v}(t)"
+                ax=ax, ylim=(None, None), sharex=True,
+                title=f"{self.model.NAME}: Comparison regarding {v}(t)"
             )
             ax.yaxis.set_major_formatter(ScalarFormatter(useMathText=True))
             ax.ticklabel_format(style="sci", axis="y", scilimits=(0, 0))
@@ -423,8 +451,8 @@ class Estimator(Term):
             ScalarFormatter(useMathText=True))
         axes.ravel()[0].ticklabel_format(
             style="sci", axis="y", scilimits=(0, 0))
-        axes.ravel()[0].legend(bbox_to_anchor=(1.02, 0),
-                               loc="lower left", borderaxespad=0)
+        axes.ravel()[0].legend(
+            bbox_to_anchor=(1.02, 0), loc="lower left", borderaxespad=0)
         fig.tight_layout()
         # Save figure or show figure
         if filename is None:
